--
-- MurrayOctaQuad_front
-- Specialization for Murray Octa-Quad front animations
--
-- @author  Stefan Maurus	
-- @date  2015-04-04

-- Copyright © Stefan Maurus, www.stefanmaurus.de

MurrayOctaQuad_front = {};

function MurrayOctaQuad_front.prerequisitesPresent(specializations)
    return true;
end;

function MurrayOctaQuad_front:load(xmlFile)
	self.foldForkAnimation = SpecializationUtil.callSpecializationsFunction("foldForkAnimation");

	self.foldForkAnimationName = getXMLString(xmlFile, "vehicle.foldForkAnimation#name");	
	self.foldForkAnimationSpeed = getXMLFloat(xmlFile, "vehicle.foldForkAnimation#speed");
	self.foldForkAnimationState = false;
end;

function MurrayOctaQuad_front:delete()
end;

function MurrayOctaQuad_front:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MurrayOctaQuad_front:keyEvent(unicode, sym, modifier, isDown)
end;

function MurrayOctaQuad_front:readStream(streamId, connection)
	self:foldForkAnimation(i, streamReadBool(streamId), true);
end;

function MurrayOctaQuad_front:writeStream(streamId, connection) 	
	streamWriteBool(streamId, self.foldForkAnimationState); 
end;

function MurrayOctaQuad_front:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	local state = Utils.getNoNil(getXMLBool(xmlFile, key.."#state"), false);
	self:foldForkAnimation(state);

	return BaseMission.VEHICLE_LOAD_OK;
end;

function MurrayOctaQuad_front:getSaveAttributesAndNodes(nodeIdent)
	local attributes = ' state="'..tostring(self.foldForkAnimationState)..'"';

	return attributes, nil;
end;

function MurrayOctaQuad_front:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
			self:foldForkAnimation(not self.foldForkAnimationState);
		end;	
	end;
end;

function MurrayOctaQuad_front:updateTick(dt)
end;

function MurrayOctaQuad_front:draw()
	if self.foldForkAnimationState then
		g_currentMission:addHelpButtonText(g_i18n:getText("OCTAQUAD_FRONT_FOLDDOWN"), InputBinding.IMPLEMENT_EXTRA2);
	else
		g_currentMission:addHelpButtonText(g_i18n:getText("OCTAQUAD_FRONT_FOLDUP"), InputBinding.IMPLEMENT_EXTRA2);
	end;
end;

function MurrayOctaQuad_front:foldForkAnimation(state, noEventSend)
	self.foldForkAnimationState = state;
	if state then
		self:playAnimation(self.foldForkAnimationName, self.foldForkAnimationSpeed);
	else
		self:playAnimation(self.foldForkAnimationName, -self.foldForkAnimationSpeed);
	end;
	SetFoldAnimationStateEvent.sendEvent(self, i, state, noEventSend);
end;

SetFoldAnimationStateEvent = {};
SetFoldAnimationStateEvent_mt = Class(SetFoldAnimationStateEvent, Event);

InitEventClass(SetFoldAnimationStateEvent, "SetFoldAnimationStateEvent");

function SetFoldAnimationStateEvent:emptyNew()
    local self = Event:new(SetFoldAnimationStateEvent_mt);
    self.className="SetFoldAnimationStateEvent";
    return self;
end;

function SetFoldAnimationStateEvent:new(vehicle, state)
    local self = SetFoldAnimationStateEvent:emptyNew()
    self.vehicle = vehicle;
	self.state = state;
    return self;
end;

function SetFoldAnimationStateEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
    self.vehicle = networkGetObject(id);

	self.state = streamReadBool(streamId);

	if self.vehicle ~= nil then
		self.vehicle:foldForkAnimation(self.state, true);
	end;
	
	if not connection:getIsServer() then
        g_server:broadcastEvent(SetFoldAnimationStateEvent:new(self.vehicle, self.state), nil, connection, self.vehicle);
    end;
end;

function SetFoldAnimationStateEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.vehicle));
	streamWriteBool(streamId, self.state); 
end;

function SetFoldAnimationStateEvent.sendEvent(vehicle, state, noEventSend)
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then
			g_server:broadcastEvent(SetFoldAnimationStateEvent:new(vehicle, state), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(SetFoldAnimationStateEvent:new(vehicle, state));
		end;
	end;
end;